View source: R/old_code/bluehill_functions.2.R View source: R/bluehill_functions.R
| bh_invert | R Documentation |
Compression is defined as negative, so compressive tests have negative Load and Extension.
Bluehill provides Compressive Load and Compressive Extension, but these are
not in every test, so this function inverts Load and Extension so that every
test will be the same way up (i.e. move from low to high extension and low to high load).
bh_invert(study_data)
study_data |
A |
The same data.table with -1.0 * Load and -1.0 * Extension
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.