View source: R/old_code/bluehill_functions.2.R View source: R/bluehill_functions.R
| bh_normalise | R Documentation |
Compression is defined as negative, so compressive tests have negative Load and Extension.
Bluehill provides Compressive Load and Compressive Extension, but these are
not in every test, so this function checks if Load is going negative
(i.e. a compressive test) and if so inverts Load and Extension so
that the test will move from low to high extension and low to high load.
bh_normalise(study_data)
study_data |
A |
The same data.table with Load and Extension always going from low to high
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.