View source: R/old_code/bluehill_functions.2.R View source: R/bluehill_functions.R
| bh_read_header | R Documentation |
RawData files can contain header rows that describe the test as
parameter : value pairs. This function reads any parameters into
a data.table with columns for "type", "var", "value" and "units".
A special var blank_row of type information is added at
the end with the row number of the end of the header, or 0 if there was
no header in the file. This can be passed to bh_read_data.
bh_read_header(filename)
filename |
the RawData file to process |
A data.table with any parameter : value pairs and
the special header blank_row indicating the end of the header,
or 0 if there was no header.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.